@@ -13,7 +13,7 @@ warnings.warn(
     "The 'nbdev_squ' import name is deprecated. Please use 'wagov_squ' instead. "
     "Support for 'nbdev_squ' will be removed in a future version.",
     DeprecationWarning,
-    stacklevel=2
+    stacklevel=2,
 )
 
 # Make nbdev_squ act as an alias to wagov_squ
