@@ -40,43 +40,6 @@ def test_jira_client_cloud_support():
                 )
 
 
-def test_jira_basic_usage():
-    """Test that we can use standard Jira API methods."""
-    from wagov_squ.api import Clients
-
-    with patch("wagov_squ.api.login"), patch("wagov_squ.api.load_config", return_value={}):
-        clients = Clients()
-
-        # Mock the entire chain
-        with (
-            patch.object(clients, "config") as mock_config,
-            patch("wagov_squ.api.Jira") as mock_jira,
-        ):
-            mock_config.jira_url = "https://example.atlassian.net"
-            mock_config.jira_username = "user"
-            mock_config.jira_password = "pass"
-
-            mock_jira_instance = Mock()
-            mock_jira.return_value = mock_jira_instance
-
-            # Mock jql response
-            mock_response = {
-                "issues": [{"id": "1", "key": "TEST-1"}],
-                "startAt": 0,
-                "maxResults": 100,
-                "total": 1,
-            }
-            mock_jira_instance.jql.return_value = mock_response
-
-            jira_client = clients.jira
-
-            # Test calling standard jql method
-            jira_client.jql("project = TEST")
-
-            # Verify the jql method was called
-            mock_jira_instance.jql.assert_called_once_with("project = TEST")
-
-
 def test_jira_client_creation():
     """Test that Jira client is created correctly."""
     from wagov_squ.api import Clients
